@@ -1,5 +1,6 @@
 import json
 import os
+from socket import timeout
 
 from nornir.core.exceptions import ConnectionNotOpen, NornirExecutionError
 from nornir_pyez.plugins.tasks import pyez_config, pyez_diff, pyez_commit
@@ -25,7 +26,7 @@ EXECUTION_STATUS = {
     'SUCCESSFULL': 'successfull',
 }
 
-def try_apply_config(config_file_path, retries=3, check_params=None, commit=False):
+def try_apply_config(config_file_path, retries=3, check_params=None, commit=False, rollback_error=True):
     """
 	TODO: write docstrings
 	"""
@@ -51,8 +52,15 @@ def try_apply_config(config_file_path, retries=3, check_params=None, commit=Fals
         print("Configuration apply has FAILED!")
         exit(1)
     elif exec_status == EXECUTION_STATUS['ROLLBACK']:
-        print("Configuration databases has been ROLLBACKED! Please, check what happened in previous tests!")
-        exit(1)
+        print("Configuration databases has been ROLLBACKED!")
+        print("Rollback error:", rollback_error)
+        if rollback_error:
+            # If it must generate an error state when rollbacked
+            print("Please, check what happened in previous tests!")
+            exit(1)
+        else:
+            # When it must not generate error state when rollbacked
+            exit(0)
  
     return
 
@@ -221,18 +229,25 @@ def junos_rollback(host, device_name, rb_id=1):
     try:
         print ("Rolling back the configuration")
         cu.rollback(rb_id=rb_id)
+        print ("Compare the candidate configuration to the rollback configuration:")
+        cu.pdiff()
         print ("Committing the configuration")
-        cu.commit()
+        cu.commit(timeout=60)
     except CommitError as err:
         print ("Error: Unable to commit configuration: {0}".format(err))
+        dev.close()
+        exit(1)
     except RpcError as err:
         print ("Unable to roll back configuration changes: {0}".format(err))
-
+        dev.close()
+        exit(1)
     finally:
         print ("Unlocking the configuration")
         try:
             cu.unlock()
         except UnlockError as err:
             print ("Unable to unlock configuration: {0}".format(err))
+            dev.close()
+            exit(1)
         dev.close()
         return
\ No newline at end of file
