@@ -3,7 +3,8 @@ import yaml
 import os
 import sys
 
-from PDFWriter import PDFWriter
+#from PDFWriter import PDFWriter
+from fpdf import FPDF
 
 
 def merge_dicts(dictionary):
@@ -92,37 +93,26 @@ def remove_empty_lines(filename):
 
     return
 
-def error_exit(message):
-    """TODO write docstring"""
-    sys.stderr.write(message)
-    sys.exit(1)
-
-def json_to_pdf(json_data):
-    """TODO write docstring"""
-    # Get the data values from the JSON string json_data.
-    try:
-        data = json.loads(json_data)
-        pdf_filename = data['pdf_filename']
-        font_name = data['font_name']
-        font_size = data['font_size']
-        header = data['header']
-        footer = data['footer']
-        lines = data['lines']
-    except Exception as e:
-        error_exit("Invalid JSON data: {}".format(e.message))
-    # Generate the PDF using the data values.
-    try:
-        with PDFWriter(pdf_filename) as pw:
-            pw.setFont(font_name, font_size)
-            pw.setHeader(header)
-            pw.setFooter(footer)
-            for line in lines:
-                pw.writeLine(line)
-    except IOError as ioe:
-        error_exit("IOError while generating PDF file: {}".format(ioe.message))
-    except Exception as e:
-        error_exit("Error while generating PDF file: {}".format(e.message))
+def text_to_pdf(txt_data):
+    # save FPDF() class into 
+    # a pdf object
+    pdf = FPDF()   
+    # Add a page
+    pdf.add_page()
     
+    # Set style and size of font 
+    pdf.set_font(
+        txt_data['font_name'], 
+        size=txt_data['font_size']
+    )
+    
+    # Insert the texts in pdf
+    for x in txt_data['lines']:
+        pdf.cell(200, 10, txt = x, ln = 1, align = 'J')
+    
+    # Save the pdf with name
+    pdf.output(txt_data['pdf_filename'])
+
     return
 
 def convert_txt_to_pdf(file_path):
@@ -138,11 +128,9 @@ def convert_txt_to_pdf(file_path):
             'font_name': 'Courier',
             'font_size': 12,
             'header': file_header,
-            'footer': 'Generated by xtopdf - http://google.com/search?q=xtopdf',
             'lines': lines
         }
-        json_data = json.dumps(data)
-        json_to_pdf(json_data)
+        text_to_pdf(data)
     print(f"PDF file converted from {ori_filename} to {pdf_filename}")
     
     return pdf_filename
\ No newline at end of file
