@@ -4,6 +4,7 @@ import json
 from ..infra.infra import import_infra_data
 from ..api.netbox.netbox_manager import NetboxManager
 from ..api.netbox.util import get_sot_filter_parameters
+from ..utils.utils import convert_txt_to_pdf
 from .reachability import reachability_tests
 from .traceroute import traceroute_tests
 from .junos.tests import junos_ping
@@ -117,6 +118,7 @@ def run_tests(infra_file_path, test_type, infra_key, results_file_path, reach_te
             json_object = json.dumps(result, indent = 4)
             with open(results_file_path, "w") as outfile:
                 outfile.write(json_object)
+            convert_txt_to_pdf(results_file_path)
             exit(0)
         else:
             print("Reachability tests FAILED")
